@@ -6,6 +6,11 @@ from twisted.web.client import HTTPClientFactory, _parse
 import dateutil.parser
 from .unicodeconverter import convertToUTF8
 from OpenSSL import SSL
+import logging
+
+
+LOGGER = logging.getLogger("main")
+
 
 class AllCipherSSLClientContextFactory(ssl.ClientContextFactory):
     """A context factory for SSL clients that uses all ciphers."""
@@ -33,7 +38,7 @@ class RequestQueuer(object):
     # Dictionary of user specified maximum simultaneous requests, by host
     max_simul_reqs_per_hosts = {}
     
-    def __init__(self, max_simultaneous_requests=20,
+    def __init__(self, max_simultaneous_requests=50,
                  max_requests_per_host_per_second=1,
                  max_simultaneous_requests_per_host=5): 
         """
@@ -257,9 +262,8 @@ class RequestQueuer(object):
         return True
 
     def _checkActive(self):
-        
-        #self.pending_reqs = dict([(x[0],x[1]) for x in filter(lambda x:len(x[1]) > 0, self.pending_reqs.items())])
-        while self.getActive() < self.max_simul_reqs and self.getPending() > 0:        
+        while self.getActive() < self.max_simul_reqs and self.getPending() > 0:     
+            LOGGER.critical("CHECK ACTIVE LOOP")   
             in_loop_req_count = 0
             hosts = self.pending_reqs.keys()
             for host in hosts:
